# NLIF
ChatGPT API를 이용하여 자연어 문장을 조건문으로써 활용할 수 있도록 해주는 프로젝트

# 목차
- [설치](#설치)
- [활용 예시](#활용-예시)
- [Contact](#contact)

# 설치
```
pip install NLIF
```

# 활용 예시
```python
from NLIF import *

api_register("Your OpenAI API key")

if nlif('proposition'):
    pass
else:
    pass
```

# Contact
| contributer | e-mail |
|---------|---------|
| marmot8080 | marmot8080@gmail.com |